@@ -9,7 +9,7 @@
    // Copyright (C) 2013, 2018, 2019 Adam Reichold <adamreichold@myopera.com>
    // Copyright (C) 2013 Dmytro Morgun <lztoad@gmail.com>
    // Copyright (C) 2017 Christoph Cullmann <cullmann@kde.org>
-   // Copyright (C) 2017, 2018, 2020, 2021 Albert Astals Cid <aacid@kde.org>
+   // Copyright (C) 2017, 2018, 2020-2022 Albert Astals Cid <aacid@kde.org>
    // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
    // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
    // Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
@@ -505,7 +505,7 @@ GooString *GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *ty
     const GooString *fontName = font->getName();
     if (!fontName)
         return nullptr;
-    std::unique_lock<std::recursive_mutex> locker(mutex);
+    const std::scoped_lock locker(mutex);
     setupBaseFonts(POPPLER_FONTSDIR);
 
     // TODO: base14Name should be changed?
