@@ -13,7 +13,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2007, 2011, 2018, 2019, 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007, 2011, 2018, 2019, 2021, 2022 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006 Rainer Keller <class321@gmx.de>
 // Copyright (C) 2008 Timothy Lee <timothy.lee@siriushk.com>
 // Copyright (C) 2008 Vasile Gaburici <gaburici@cs.umd.edu>
@@ -688,7 +688,7 @@ void ImageOutputDev::drawMaskedImage(GfxState *state, Object *ref, Stream *str,
 {
     if (listImages) {
         listImage(state, ref, str, width, height, colorMap, interpolate, false, imgImage);
-        listImage(state, ref, str, maskWidth, maskHeight, nullptr, maskInterpolate, false, imgMask);
+        listImage(state, ref, maskStr, maskWidth, maskHeight, nullptr, maskInterpolate, false, imgMask);
     } else {
         writeImage(state, ref, str, width, height, colorMap, false);
         writeImage(state, ref, maskStr, maskWidth, maskHeight, nullptr, false);
